@@ -145,6 +145,29 @@ class SQLPickle(object):
         #return (deserialise(row['key']) for row in rows)
         return [deserialise(row['key']) for row in rows]
 
+    def update(self, E, **F):
+        """ D.update(E, **F) -> None.  Update D from dict/iterable E and F.
+            If E has a .keys() method, does:     for k in E: D[k] = E[k]
+            If E lacks .keys() method, does:     for (k, v) in E: D[k] = v
+            In either case, this is followed by: for k in F: D[k] = F[k]
+        """
+        # TODO: could optimize this to do one SQL call rather than many.
+        if hasattr(E, 'keys'):
+            for k in E: 
+                #D[k] = E[k]
+                self.save(k, E[k])
+        else:
+            for (k, v) in E: 
+                #D[k] = v
+                self.save(k, v)
+
+        for k in F: 
+            self.save(k, F[k])
+        
+
+
+
+
     def items(self):
         """ items() returns a generator of (key,value) pairs.
         """
