@@ -98,6 +98,23 @@ class TestSQLPickle(unittest.TestCase):
 
 
 
+    def test_update(self):
+        """ does update({}) work?
+        """
+        p = sqlitepickle.SQLPickle()
+        key, value = 'asdf', 'qwer'
+        p.save(key, value)
+        p.save('rtyu', 2)
+        self.assertEqual(list(p.keys()), ['asdf', 'rtyu'])
+        self.assertEqual(list(p.items()), [('asdf', 'qwer'), ('rtyu', 2)])
+
+        # we update one element.
+        p.update({'rtyu':99})
+        self.assertEqual(list(p.items()), [('asdf', 'qwer'), ('rtyu', 99)])
+
+        # we update two elements, and add one.
+        p.update({'rtyu':99, 'asdf':66, 'qwer':77})
+        self.assertEqual(list(p.items()), [('asdf', 66), ('rtyu', 99), ('qwer',77)])
 
 
 
